@@ -76,9 +76,9 @@ GameView::GameView( QWidget *parent, Game *game )
                            col.light(),        col.dark(),   col,
                            col.dark(75),       col.dark(75), col.dark(), 
                            Qt::black );
-    palette.setColorGroup( QPalette::Disabled, Qt::white,    Qt::black,
+    palette.setColorGroup( QPalette::Disabled, Qt::white,    QColor(Qt::darkGray).darker(),
                            col.light(),        col.dark(),   col,
-                           col.dark(75),       col.dark(75), Qt::black,
+                           col.darker(150),    col.dark(75), Qt::black,
                            Qt::black );
     
     blackPal.setColor( QPalette::Base, Qt::black );
@@ -467,6 +467,15 @@ GameView::startNewGame()
     delete newGame;
 
     foreach (Player *player, m_game->players()) {
+        if (player->isSpectator()) {
+
+            // All planets a spectator player has assigned are turned into
+            // neutral planets so that a spectator player starts without
+            // any planet.
+
+            m_game->map()->turnOverPlayerPlanets(player, m_game->neutral());
+        }
+
         LocalPlayer *local = qobject_cast<LocalPlayer*>(player);
         if (local)
             connect(local, SIGNAL(canPlay()), this, SLOT(turn()));
@@ -484,7 +493,7 @@ GameView::startNewGame()
     // Set up the base GUI for a new game.
     m_msgWidget->clear();
     m_shipCountEdit->show();
-    m_shipCountEdit->setEnabled(true);
+    m_shipCountEdit->setEnabled(false);
     m_initCompleted = true;
 
     //call GameView::gameOver now if needed happens if the game ends immiedently after starting.
